==> cdk-bootstrap-cleanup-0.0.0.tgz: package/API.md <==
# API Reference <a name="API Reference" id="api-reference"></a>

## Constructs <a name="Constructs" id="Constructs"></a>

### BootstrapCleanup <a name="BootstrapCleanup" id="cdk-bootstrap-cleanup.BootstrapCleanup"></a>

Construct to clean up a given asset.

#### Initializers <a name="Initializers" id="cdk-bootstrap-cleanup.BootstrapCleanup.Initializer"></a>

```typescript
import { BootstrapCleanup } from 'cdk-bootstrap-cleanup'

new BootstrapCleanup(scope: Construct, id: string, props: BootstrapCleanupProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk-bootstrap-cleanup.BootstrapCleanup.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | *No description.* |
| <code><a href="#cdk-bootstrap-cleanup.BootstrapCleanup.Initializer.parameter.id">id</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk-bootstrap-cleanup.BootstrapCleanup.Initializer.parameter.props">props</a></code> | <code><a href="#cdk-bootstrap-cleanup.BootstrapCleanupProps">BootstrapCleanupProps</a></code> | *No description.* |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk-bootstrap-cleanup.BootstrapCleanup.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

---

##### `id`<sup>Required</sup> <a name="id" id="cdk-bootstrap-cleanup.BootstrapCleanup.Initializer.parameter.id"></a>

- *Type:* string

---

##### `props`<sup>Required</sup> <a name="props" id="cdk-bootstrap-cleanup.BootstrapCleanup.Initializer.parameter.props"></a>

- *Type:* <a href="#cdk-bootstrap-cleanup.BootstrapCleanupProps">BootstrapCleanupProps</a>

---





## Structs <a name="Structs" id="Structs"></a>

### BootstrapCleanupProps <a name="BootstrapCleanupProps" id="cdk-bootstrap-cleanup.BootstrapCleanupProps"></a>

#### Initializer <a name="Initializer" id="cdk-bootstrap-cleanup.BootstrapCleanupProps.Initializer"></a>

```typescript
import { BootstrapCleanupProps } from 'cdk-bootstrap-cleanup'

const bootstrapCleanupProps: BootstrapCleanupProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk-bootstrap-cleanup.BootstrapCleanupProps.property.bucket">bucket</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk-bootstrap-cleanup.BootstrapCleanupProps.property.key">key</a></code> | <code>string</code> | *No description.* |

---

##### `bucket`<sup>Required</sup> <a name="bucket" id="cdk-bootstrap-cleanup.BootstrapCleanupProps.property.bucket"></a>

```typescript
public readonly bucket: string;
```

- *Type:* string

---

##### `key`<sup>Required</sup> <a name="key" id="cdk-bootstrap-cleanup.BootstrapCleanupProps.property.key"></a>

```typescript
public readonly key: string;
```

- *Type:* string

---

## Classes <a name="Classes" id="Classes"></a>

### BootstrapCleanupAspect <a name="BootstrapCleanupAspect" id="cdk-bootstrap-cleanup.BootstrapCleanupAspect"></a>

- *Implements:* aws-cdk-lib.IAspect

#### Initializers <a name="Initializers" id="cdk-bootstrap-cleanup.BootstrapCleanupAspect.Initializer"></a>

```typescript
import { BootstrapCleanupAspect } from 'cdk-bootstrap-cleanup'

new BootstrapCleanupAspect()
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk-bootstrap-cleanup.BootstrapCleanupAspect.visit">visit</a></code> | All aspects can visit an IConstruct. |

---

##### `visit` <a name="visit" id="cdk-bootstrap-cleanup.BootstrapCleanupAspect.visit"></a>

```typescript
public visit(node: IConstruct)
```

###### `node`<sup>Required</sup> <a name="node" id="cdk-bootstrap-cleanup.BootstrapCleanupAspect.visit.parameter.node"></a>

- *Type:* constructs.IConstruct

---

==> cdk-bootstrap-cleanup-0.0.5.tgz: package/API.md <==
# CDK Bootstrap Cleanup

Status: EXPERIMENTAL

Removes objects from the shard CDK Bootstrap backup when they are not used.

This happens as part of the Stack update or delete operation. A custom resource is created for each asset. Whenever it gets changed the custom resource gets updated and CloudFormation will delete the object in its cleanup phase.

When the asset is not used anymore, also the custom resources gets deleted and the object will be deleted in the CloudFormation cleanup phase.


## Open issues
- [] Support permanent delete (at the moment only a delete marker is set)
- [] Support cross-stack scenarios
- [] custom resource should have log retention


## Other projects
...
# API Reference <a name="API Reference" id="api-reference"></a>

## Constructs <a name="Constructs" id="Constructs"></a>

### BootstrapCleanup <a name="BootstrapCleanup" id="cdk-bootstrap-cleanup.BootstrapCleanup"></a>

Construct to clean up a given asset.

#### Initializers <a name="Initializers" id="cdk-bootstrap-cleanup.BootstrapCleanup.Initializer"></a>

```typescript
import { BootstrapCleanup } from 'cdk-bootstrap-cleanup'

new BootstrapCleanup(scope: Construct, id: string, props: BootstrapCleanupProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk-bootstrap-cleanup.BootstrapCleanup.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | *No description.* |
| <code><a href="#cdk-bootstrap-cleanup.BootstrapCleanup.Initializer.parameter.id">id</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk-bootstrap-cleanup.BootstrapCleanup.Initializer.parameter.props">props</a></code> | <code><a href="#cdk-bootstrap-cleanup.BootstrapCleanupProps">BootstrapCleanupProps</a></code> | *No description.* |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk-bootstrap-cleanup.BootstrapCleanup.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

---

##### `id`<sup>Required</sup> <a name="id" id="cdk-bootstrap-cleanup.BootstrapCleanup.Initializer.parameter.id"></a>

- *Type:* string

---

##### `props`<sup>Required</sup> <a name="props" id="cdk-bootstrap-cleanup.BootstrapCleanup.Initializer.parameter.props"></a>

- *Type:* <a href="#cdk-bootstrap-cleanup.BootstrapCleanupProps">BootstrapCleanupProps</a>

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk-bootstrap-cleanup.BootstrapCleanup.toString">toString</a></code> | Returns a string representation of this construct. |

---

##### `toString` <a name="toString" id="cdk-bootstrap-cleanup.BootstrapCleanup.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk-bootstrap-cleanup.BootstrapCleanup.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="cdk-bootstrap-cleanup.BootstrapCleanup.isConstruct"></a>

```typescript
import { BootstrapCleanup } from 'cdk-bootstrap-cleanup'

BootstrapCleanup.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="cdk-bootstrap-cleanup.BootstrapCleanup.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk-bootstrap-cleanup.BootstrapCleanup.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk-bootstrap-cleanup.BootstrapCleanup.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---


## Structs <a name="Structs" id="Structs"></a>

### BootstrapCleanupProps <a name="BootstrapCleanupProps" id="cdk-bootstrap-cleanup.BootstrapCleanupProps"></a>

#### Initializer <a name="Initializer" id="cdk-bootstrap-cleanup.BootstrapCleanupProps.Initializer"></a>

```typescript
import { BootstrapCleanupProps } from 'cdk-bootstrap-cleanup'

const bootstrapCleanupProps: BootstrapCleanupProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk-bootstrap-cleanup.BootstrapCleanupProps.property.bucket">bucket</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk-bootstrap-cleanup.BootstrapCleanupProps.property.key">key</a></code> | <code>string</code> | *No description.* |

---

##### `bucket`<sup>Required</sup> <a name="bucket" id="cdk-bootstrap-cleanup.BootstrapCleanupProps.property.bucket"></a>

```typescript
public readonly bucket: string;
```

- *Type:* string

---

##### `key`<sup>Required</sup> <a name="key" id="cdk-bootstrap-cleanup.BootstrapCleanupProps.property.key"></a>

```typescript
public readonly key: string;
```

- *Type:* string

---

## Classes <a name="Classes" id="Classes"></a>

### BootstrapCleanupAspect <a name="BootstrapCleanupAspect" id="cdk-bootstrap-cleanup.BootstrapCleanupAspect"></a>

- *Implements:* aws-cdk-lib.IAspect

#### Initializers <a name="Initializers" id="cdk-bootstrap-cleanup.BootstrapCleanupAspect.Initializer"></a>

```typescript
import { BootstrapCleanupAspect } from 'cdk-bootstrap-cleanup'

new BootstrapCleanupAspect()
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk-bootstrap-cleanup.BootstrapCleanupAspect.visit">visit</a></code> | All aspects can visit an IConstruct. |

---

##### `visit` <a name="visit" id="cdk-bootstrap-cleanup.BootstrapCleanupAspect.visit"></a>

```typescript
public visit(node: IConstruct): void
```

All aspects can visit an IConstruct.

###### `node`<sup>Required</sup> <a name="node" id="cdk-bootstrap-cleanup.BootstrapCleanupAspect.visit.parameter.node"></a>

- *Type:* constructs.IConstruct

---
